@@ -6,14 +6,15 @@ use v5.20;
 
 use warnings;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use Clone        ();
 use Scalar::Util qw( blessed );
 use Ref::Util    qw( is_plain_hashref is_arrayref is_regexpref is_ref );
 use Form::Tiny::Utils 'get_package_form_meta';
-use Types::Standard qw( ArrayRef Bool CodeRef Dict Enum Int Optional RegexpRef Tuple Undef Value );
-use Type::Params    qw( signature_for );
+use Types::Standard
+  qw( ArrayRef Bool CodeRef Dict Enum Int Optional RegexpRef Str Tuple Undef Value );
+use Type::Params          qw( signature_for );
 use Types::Common::String qw ( NonEmptySimpleStr NonEmptyStr );
 
 use Moo::Role;
@@ -87,6 +88,19 @@ has inherit_optargs_match => (
 
 
 
+has nested_path_sep => (
+    is      => 'rwp',
+    builder => sub { '_' },
+);
+
+
+
+
+
+
+
+
+
 
 
 
@@ -291,7 +305,7 @@ sub _create_options (
             # generate the fully qualified option name using the
             # specified field name.  the field may specify an
             # alternate option name, so use that if specified.
-            my $fq_option_name = $optargs->{name} // join( '_', $opt_path->@*, $field_name );
+            my $fq_option_name = $optargs->{name} // join( $self->nested_path_sep, $opt_path->@*, $field_name );
 
             # store the mapping between option name and fully
             # qualified normalized field name.
@@ -364,7 +378,7 @@ sub _resolve_type ( $field, $type_set ) {
     # if we add Any to OptionTypeMap and ArgumentTypeMap
 
     return $type_set->{Str}
-      if $type->name eq 'Any';
+      if index( '|Any|Path|File|Dir|', q{|} . $type->name . q{|} ) != -1;
 
     while ( defined $type ) {
         return $type_set->{ $type->name } if exists $type_set->{ $type->name };
@@ -467,6 +481,7 @@ signature_for _dsl_optargs_opts => (
         inherit_required      => Optional [Bool],
         inherit_optargs       => Optional [Bool],
         inherit_optargs_match => Optional [ArrayRef],
+        nested_path_sep       => Optional [Str],
     ],
 );
 sub _dsl_optargs_opts ( $self, $context, $args ) {
@@ -488,6 +503,9 @@ sub _dsl_optargs_opts ( $self, $context, $args ) {
         $self->_set_inherit_optargs_match( $matches );
     }
 
+    $self->_set_nested_path_sep( $args->nested_path_sep )
+      if $args->has_nested_path_sep;
+
 
 }
 
@@ -515,7 +533,7 @@ CXC::Form::Tiny::Plugin::OptArgs2::Meta - Form metaclass role for OptArgs2
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 DESCRIPTION
 
@@ -541,6 +559,12 @@ A regular expression which matches the class names of superclass forms
 to exclude from inheritance.  It defaults to C<undef> which is
 equivalent to matching everything.
 
+=head2 nested_path_sep
+
+The string used to separate paths in a nested field when creating the option name.
+It defaults to C<_>.  (Note that a name explicitly passed to the 'option' clause will
+override the generated name).
+
 =head1 METHODS
 
 =head2 optargs
